import 'package:flutter/material.dart';
import 'package:sghi_core/afya_moja_core/src/app_strings.dart';
import 'package:sghi_core/afya_moja_core/src/domain/core/entities/facility_service.dart';
import 'package:sghi_core/afya_moja_core/src/domain/value_objects/dummy_data.dart';
import 'package:sghi_core/afya_moja_core/src/presentation/buttons.dart';
import 'package:sghi_core/afya_moja_core/src/presentation/facility/custom_chip.dart';
import 'package:sghi_core/afya_moja_core/src/presentation/text_themes.dart';
import 'package:sghi_core/shared_themes/spaces.dart';
import 'package:sghi_core/user_feed/src/domain/value_objects/colors.dart';

class SearchFacilityItem extends StatelessWidget {
  const SearchFacilityItem({
    super.key,
    required this.isOpen,
    required this.facilityName,
    required this.facilityLocation,
    required this.showBookButton,
    required this.services,
    this.onMoreInfoPressed,
    this.onBookPressed,
  });
  final bool isOpen;
  final String facilityName;
  final String facilityLocation;
  final bool showBookButton;
  final VoidCallback? onMoreInfoPressed;
  final VoidCallback? onBookPressed;
  final List<FacilityService?>? services;

  @override
  Widget build(BuildContext context) {
    final int endIndex =
        (services?.length ?? 0) >= 3 ? 3 : (services?.length ?? 0);

    return Container(
      decoration: BoxDecoration(
        borderRadius: const BorderRadius.all(Radius.circular(10)),
        border: Border.all(color: primaryPurpleColor.withOpacity(.3)),
        color: primaryPurpleColor.withOpacity(.1),
      ),
      padding: const EdgeInsets.all(16),
      child: Column(
        children: <Widget>[
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Flexible(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    Row(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: <Widget>[
                        Flexible(
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: <Widget>[
                              Text(
                                facilityName,
                                style: boldSize18Text(primaryPurpleColor),
                                maxLines: 1,
                                overflow: TextOverflow.ellipsis,
                              ),
                              smallVerticalSizedBox,
                              Row(
                                children: <Widget>[
                                  const Icon(
                                    Icons.location_on_outlined,
                                    color: primaryPurpleColor,
                                    size: 18,
                                  ),
                                  Flexible(
                                    child: Text(
                                      facilityLocation.isNotEmpty
                                          ? facilityLocation
                                          : dummyAddressString,
                                      style: normalSize14Text(grey1TextColor),
                                      maxLines: 1,
                                      overflow: TextOverflow.ellipsis,
                                    ),
                                  ),
                                ],
                              ),
                            ],
                          ),
                        ),
                        smallHorizontalSizedBox,
                        // facility status chip
                        CustomChip(
                          title: isOpen ? openString : closedString,
                          backgroundColor: isOpen
                              ? greenColor.withOpacity(.3)
                              : reactionIconRedColor.withOpacity(.3),
                          textColor: isOpen ? greenColor : redColor,
                        ),
                      ],
                    ),
                    smallVerticalSizedBox,
                    Wrap(
                      runSpacing: 10,
                      spacing: 10,
                      children: (services?.isNotEmpty ?? false)
                          ? services!
                              .map(
                                (FacilityService? service) => CustomChip(
                                  title: service?.name ?? '',
                                  backgroundColor:
                                      primaryPurpleColor.withOpacity(.3),
                                  textColor: primaryPurpleColor,
                                ),
                              )
                              .toList()
                              .sublist(0, endIndex)
                          : <Widget>[
                              CustomChip(
                                title: prepString,
                                backgroundColor:
                                    primaryPurpleColor.withOpacity(.3),
                                textColor: primaryPurpleColor,
                              ),
                              CustomChip(
                                title: artString,
                                backgroundColor:
                                    primaryPurpleColor.withOpacity(.3),
                                textColor: primaryPurpleColor,
                              ),
                              CustomChip(
                                title: pepString,
                                backgroundColor:
                                    primaryPurpleColor.withOpacity(.3),
                                textColor: primaryPurpleColor,
                              ),
                            ],
                    )
                  ],
                ),
              ),
            ],
          ),
          mediumVerticalSizedBox,
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Expanded(
                child: MyAfyaHubPrimaryButton(
                  text: moreInfoString,
                  textColor: primaryPurpleColor,
                  buttonColor: primaryPurpleColor.withOpacity(.3),
                  customRadius: 8,
                  borderColor: Colors.transparent,
                  customPadding:
                      const EdgeInsets.symmetric(horizontal: 10, vertical: 13),
                  onPressed: onMoreInfoPressed,
                ),
              ),
              if (showBookButton) smallHorizontalSizedBox,
              if (showBookButton)
                Expanded(
                  child: MyAfyaHubPrimaryButton(
                    text: bookString,
                    textColor: whiteColor,
                    buttonColor: primaryPurpleColor,
                    customRadius: 8,
                    customPadding: const EdgeInsets.symmetric(
                      horizontal: 10,
                      vertical: 13,
                    ),
                    onPressed: onBookPressed,
                  ),
                ),
            ],
          ),
        ],
      ),
    );
  }
}
