// Package imports:
import 'package:chewie/chewie.dart';
import 'package:flutter/services.dart';
import 'package:video_player/video_player.dart';

/// A class that initializes and configures a Chewie video player controller.
///
/// This class provides methods for initializing and configuring a Chewie video player
/// controller based on the provided `VideoPlayerController` and auto-play settings.
/// It ensures that the video player is properly initialized before creating the
/// Chewie controller. The class offers the flexibility to configure system overlays
/// and device orientations after entering full screen mode.
class VideoPlayerInitializer {
  Future<ChewieController> initializePlayer({
    required VideoPlayerController videoPlayerController,
    required bool autoPlay,
  }) async {
    if (!videoPlayerController.value.isInitialized) {
      await videoPlayerController.initialize();
    }
    return _createChewieController(autoPlay, videoPlayerController);
  }

  ChewieController _createChewieController(
    bool autoPlay,
    VideoPlayerController videoPlayerController,
  ) {
    return ChewieController(
      videoPlayerController: videoPlayerController,
      systemOverlaysAfterFullScreen: <SystemUiOverlay>[
        SystemUiOverlay.bottom,
        SystemUiOverlay.top,
      ],
      deviceOrientationsAfterFullScreen: <DeviceOrientation>[
        DeviceOrientation.portraitUp
      ],
    );
  }
}
