import 'package:flutter/material.dart';
import 'package:sghi_core/domain_objects/value_objects/enums.dart';
import 'package:sghi_core/shared_themes/spaces.dart';
import 'package:sghi_core/shared_themes/text_themes.dart';
import 'package:sghi_core/ui_components/src/app_strings.dart';
import 'package:sghi_core/ui_components/src/buttons.dart';
import 'package:sghi_core/ui_components/src/profile_avatar.dart';

class SILProfileBanner extends StatelessWidget {
  const SILProfileBanner(
      {required this.backgroundImagePath,
      required this.userPhotoPath,
      required this.profileRoute,
      required this.userName,
      required this.primaryPhone,
      required this.gender,
      this.editable = false,
      this.height = 200.00,
      this.isContactPage = false});

  final String backgroundImagePath;
  final bool editable;
  final double height;
  final String primaryPhone;
  final String profileRoute;
  final String userName;
  final String userPhotoPath;
  final String gender;
  final bool isContactPage;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: double.infinity,
      height: height,
      decoration: BoxDecoration(
        image: DecorationImage(
          fit: BoxFit.cover,
          image: AssetImage(backgroundImagePath),
        ),
        borderRadius: const BorderRadius.only(
          bottomLeft: Radius.circular(6),
          bottomRight: Radius.circular(6),
        ),
      ),
      child: Stack(
        clipBehavior: Clip.none,
        children: <Widget>[
          Container(
            width: double.infinity,
            height: 200,
            decoration: BoxDecoration(
              gradient: LinearGradient(colors: <Color>[
                Theme.of(context).primaryColor.withOpacity(0.8),
                Theme.of(context).primaryColor.withOpacity(0.4),
              ], begin: Alignment.bottomLeft, end: Alignment.topRight),
            ),
          ),
          Positioned(
            bottom: -60,
            left: 0,
            right: 0,
            child: Container(
              width: 90,
              height: 90,
              decoration: BoxDecoration(
                shape: BoxShape.circle,
                border: Border.all(
                  width: 2,
                  color: Theme.of(context).primaryColor.withOpacity(0.6),
                ),
              ),
              child: SILProfileAvatar(
                  photoPath: gender == Gender.female.toString()
                      ? femaleUserIconPath
                      : maleUserIconPath),
            ),
          ),
          Positioned(
            bottom: isContactPage ? -105 : -110,
            left: 0,
            right: 0,
            child: Column(
              children: <Widget>[
                Text(
                  userName,
                  style: TextThemes.heavySize16Text(Colors.black),
                ),
                verySmallVerticalSizedBox,
                if (isContactPage)
                  const SizedBox()
                else
                  Text(
                    primaryPhone,
                    style: TextThemes.normalSize14Text(Colors.black),
                  ),
              ],
            ),
          ),
          Padding(
            padding: const EdgeInsets.fromLTRB(15, 50, 15, 0),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: <Widget>[
                IconButton(
                  icon: const Icon(
                    Icons.arrow_back,
                    color: Colors.white,
                  ),
                  onPressed: () {
                    Navigator.pop(context);
                  },
                ),
                if (isContactPage)
                  const SizedBox()
                else
                  Opacity(
                    opacity: 0.75,
                    child: SILSecondaryButton(
                        onPressed: () {
                          Navigator.pushNamed(context, profileRoute);
                        },
                        text: 'Edit Profile',
                        borderColor: Colors.white,
                        textColor: Colors.white,
                        addBorder: true,
                        customRadius: 5),
                  )
              ],
            ),
          )
        ],
      ),
    );
  }
}
