// Flutter imports:
import 'package:flutter/material.dart';
// Package imports:
import 'package:flutter_test/flutter_test.dart';
import 'package:sghi_core/afya_moja_core/afya_moja_core.dart';
import 'package:sghi_core/ui_components/src/buttons.dart';

import '../user_feed/test_helpers.dart';

void main() {
  group('OnboardingScaffold', () {
    testWidgets('should render correctly', (WidgetTester tester) async {
      await tester.pumpWidget(
        const MaterialApp(
          home: OnboardingScaffold(
            showBackButton: true,
            title: 'My Afya Hub Onboarding Scaffold',
            description: 'test My Afya Hub Onboarding Scaffold',
            child: Text('Test'),
          ),
        ),
      );
      await tester.pump();
      expect(find.byType(OnboardingScaffoldHeader), findsOneWidget);
    });

    testWidgets('should render correctly without title and description',
        (WidgetTester tester) async {
      await tester.pumpWidget(
        const MaterialApp(
          home: OnboardingScaffold(
            title: '',
            description: '',
            child: Text('Test'),
          ),
        ),
      );
      await tester.pumpAndSettle();
      expect(find.byType(OnboardingScaffoldHeader), findsNothing);
      expect(find.text('Test'), findsOneWidget);
    });

    testWidgets('back button navigates correctly', (WidgetTester tester) async {
      await buildTestWidget(
        tester: tester,
        child: Scaffold(
          body: Builder(builder: (BuildContext context) {
            return SILPrimaryButton(
              onPressed: () {
                Navigator.push(
                  context,
                  MaterialPageRoute<dynamic>(
                    builder: (BuildContext context) => const OnboardingScaffold(
                      title: 'Test',
                      description: 'description',
                      showBackButton: true,
                      child: SizedBox(),
                    ),
                  ),
                );
              },
            );
          }),
        ),
      );
      final Finder silButtonFinder = find.byType(SILPrimaryButton);
      final Finder iconButtonFinder = find.byType(IconButton);

      await tester.pumpAndSettle();
      expect(silButtonFinder, findsOneWidget);
      await tester.tap(silButtonFinder);
      await tester.pumpAndSettle();

      expect(find.byType(OnboardingScaffoldHeader), findsOneWidget);
      expect(iconButtonFinder, findsOneWidget);
      await tester.tap(iconButtonFinder);

      await tester.pumpAndSettle();
      expect(silButtonFinder, findsOneWidget);
    });

    testWidgets('sets background color', (WidgetTester tester) async {
      await tester.pumpWidget(
        const MaterialApp(
          home: OnboardingScaffold(
            backgroundColor: Colors.white,
            title: 'My Afya Hub Onboarding Scaffold',
            description: 'test My Afya Hub Onboarding Scaffold',
            child: Text('Test'),
          ),
        ),
      );
      await tester.pump();
      expect(
        (tester.firstWidget(find.byType(OnboardingScaffold))
                as OnboardingScaffold)
            .backgroundColor,
        Colors.white,
      );
    });
  });
}
