// Package imports:
import 'package:flutter_test/flutter_test.dart';
import 'package:sghi_core/communities/models/room_user.dart';
import 'package:sghi_core/communities/models/strings.dart';
import 'package:sghi_core/communities/models/user.dart';

import '../../response_mocks.dart';

void main() {
  test('User should convert from/to json', () {
    final User state = User.initial();
    final Map<String, dynamic> result = state.toJson();

    expect(result, isA<Map<String, dynamic>>());
    expect(result.containsKey('display_name'), true);
    expect(result['display_name'], UNKNOWN);

    final User result2 = User.fromJson(loginResponseMock);

    expect(result2.displayName, isNotNull);
    expect(result2.displayName, 'Abiud Orina');
    expect(result2.accessToken, isNotNull);
    expect(result2.accessToken, 'some-sample-token');
    expect(result2.isSignedIn, isTrue);
  });

  test('RoomUser should convert from/to json', () {
    final RoomUser state = RoomUser.initial();
    final Map<String, dynamic> result = state.toJson();

    expect(result, isA<Map<String, dynamic>>());
    expect(result.containsKey('power_level'), true);
    expect(result['power_level'], 0);

    final RoomUser result2 = RoomUser.fromJson(<String, dynamic>{
      'power_level': 100,
      'moderator': true,
      'room_user': User.initial()
          .copyWith
          .call(displayName: 'Abiud Orina again')
          .toJson(),
    });

    expect(result2.powerLevel, 100);
    expect(result2.moderator, isTrue);
    expect(result2.roomUser?.displayName, 'Abiud Orina again');
  });
}
