import 'dart:io';

import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:sghi_core/communities/components/avatar.dart';

import '../mock_image_http_client.dart';

void main() {
  group('Avatar', () {
    setUp(() {
      HttpOverrides.global = TestHttpOverrides();
    });

    testWidgets('should return initials if an avatar uri is missing or unknown',
        (WidgetTester tester) async {
      await tester.pumpWidget(
        const MaterialApp(
          home: Avatar(
            avatarURI: 'UNKNOWN',
            displayName: 'Test User',
            color: Colors.white,
            baseUrl: '',
            mediaServerUrl: '',
          ),
        ),
      );

      expect(find.byType(Avatar), findsOneWidget);
      expect(find.text('TU'), findsOneWidget);
    });

    testWidgets('should show an avatar', (WidgetTester tester) async {
      await tester.pumpWidget(
        const MaterialApp(
          home: Avatar(
            avatarURI: 'some-avatar-uri',
            displayName: 'Test User',
            color: Colors.white,
            baseUrl: '',
            mediaServerUrl: '',
          ),
        ),
      );

      await tester.pump();

      expect(find.byType(Avatar), findsOneWidget);
      expect(find.byType(CachedNetworkImage), findsOneWidget);
    });
  });
}
